@@ -1,6 +1,6 @@
 package Fey::SQL::Update;
 BEGIN {
-  $Fey::SQL::Update::VERSION = '0.38';
+  $Fey::SQL::Update::VERSION = '0.39';
 }
 
 use strict;
@@ -150,8 +150,13 @@ sub set_clause {
         'SET ' . (
             join ', ',
             map {
-                      $self->$col_quote( $_->[0], $dbh ) . ' = '
-                    . $_->[1]->sql($dbh)
+                my $val = $_->[1];
+                my $val_sql = $val->sql($dbh);
+                $val_sql = "($val_sql)"
+                    if blessed $val
+                        && $val->can('does')
+                        && $val->does('Fey::Role::SQL::ReturnsData');
+                $self->$col_quote( $_->[0], $dbh ) . ' = ' . $val_sql;
                 } $self->_set_pairs()
         )
     );
@@ -190,7 +195,7 @@ Fey::SQL::Update - Represents a UPDATE query
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 SYNOPSIS
 
@@ -318,11 +323,11 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2010 by Dave Rolsky.
+This software is Copyright (c) 2011 by Dave Rolsky.
 
 This is free software, licensed under:
 
-  The Artistic License 2.0
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
 
